package com.yunfeiyun.agmp.fms.service;

import com.yunfeiyun.agmp.fms.domain.FmsTaskpatrol;
import com.yunfeiyun.agmp.fms.domain.reqvo.FmsTaskPatrolListReqVo;
import com.yunfeiyun.agmp.fms.domain.resvo.FmsTaskPatrolListResVo;

import java.util.List;

/**
 * 巡田Service接口
 * 
 * @author 杨晓辉
 * @date 2023-05-23
 */
public interface IFmsTaskpatrolService 
{
    /**
     * 查询巡田
     * 
     * @param taskpatrolId 巡田主键
     * @return 巡田
     */
    public FmsTaskpatrol selectFmsTaskpatrolByTaskpatrolId(String taskpatrolId);

    /**
     * 查询巡田列表
     * 
     * @param fmsTaskPatrolListReqVo 巡田
     * @return 巡田集合
     */
    public List<FmsTaskPatrolListResVo> selectFmsTaskpatrolList(FmsTaskPatrolListReqVo fmsTaskPatrolListReqVo);

    /**
     * 新增巡田
     * 
     * @param fmsTaskPatrolListResVo 巡田
     * @return 结果
     */
    public int insertFmsTaskpatrol(FmsTaskpatrol fmsTaskPatrolListResVo);

    /**
     * 修改巡田
     * 
     * @param fmsTaskPatrolListResVo 巡田
     * @return 结果
     */
    public int updateFmsTaskpatrol(FmsTaskpatrol fmsTaskPatrolListResVo);

    /**
     * 批量删除巡田
     * 
     * @param taskpatrolIds 需要删除的巡田主键集合
     * @return 结果
     */
    public int deleteFmsTaskpatrolByTaskpatrolIds(String[] taskpatrolIds);

    /**
     * 删除巡田信息
     * 
     * @param taskpatrolId 巡田主键
     * @return 结果
     */
    public int deleteFmsTaskpatrolByTaskpatrolId(String taskpatrolId);
}
